@@ -1,4 +1,8 @@
 #!/usr/bin/env python
+
+from tkinter import W
+import get
+
 import rich_click as click
 from click_shell import shell
 
@@ -16,25 +20,14 @@ click.rich_click.OPTION_GROUPS = {
 }
 
 
-def print_version(ctx, param, value):
-    if not value or ctx.resilient_parsing:
-        return
-    version_file = open("version.txt", "r")
-    version = version_file.read()
-    version_file.close()
-    click.echo(version)
-    ctx.exit()
-
-
-@click.option(
-    "--version", is_flag=True, callback=print_version, expose_value=False, is_eager=True
-)
 @shell(prompt="ff > ", intro="Starting ff...")
 @click.pass_context
 def cli(ctx):
 
-    print("hi")
+    #TODO: Pass something if needed in near future
+    ctx.obj = {}
 
+cli.add_command(get.get)
 
 if __name__ == "__main__":
 
